@@ -62,6 +62,11 @@ class Coordinator:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.stop()
 
+    def kill(self):
+        for proc in self._processes:
+            if proc:
+                proc.terminate()
+
     def stop(self, delay=None):
         # shouldn't be any procs left, but just in case
         for proc in self._processes:
@@ -153,6 +158,7 @@ class Coordinator:
         :param session: Pytest test session, to get session or config information
         """
         reader_mapping = {q._reader: q for q in self._result_qs}
+
         def read_results(timeout=0):
             available_qs = [q._reader for q in self._result_qs if q is not None]
             (inputs, _, _) = select.select(available_qs, [], [], timeout)
@@ -166,12 +172,12 @@ class Coordinator:
 
         #while any(self._result_qs):
         for test in self._tests:
-            if all([q is None for q in self._result_qs ]):
+            if all([q is None for q in self._result_qs]):
                 raise Exception("Tests remain but no workers left to process them!")
             read_results()
             # Function objects in pytest are not pickle-able, so have to send string nodeid and
             # do lookup on worker side
-            item = [t.nodeid for t in test] if isinstance(test, list) else test.nodeid
+            item = [t.nodeid for t in test] if isinstance(test, list) else [test.nodeid]
             self._test_q.put(item)
 
         read_results()
